"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BackupSslCert = void 0;
const package_json_1 = __importDefault(require("../package.json"));
const shelljs_1 = __importDefault(require("shelljs"));
const chalk_1 = __importDefault(require("chalk"));
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const asg_utils_1 = require("./utils/asg-utils");
const fs_utils_1 = require("./utils/fs-utils");
const s3_utils_1 = require("./utils/s3-utils");
class BackupSslCert {
    constructor(options) {
        this.options = options;
        this.s3Client = new aws_sdk_1.default.S3({
            region: this.options.region
        });
        this.autoScalingClient = new aws_sdk_1.default.AutoScaling({
            region: this.options.region
        });
        this.instanceId = shelljs_1.default.exec(`ec2metadata --instance-id`).toString();
        this.run();
    }
    run() {
        try {
            console.log(chalk_1.default.bgGreenBright(`Running SSL certificate backup ${package_json_1.default.version}`));
            this.backupCert().finally(() => __awaiter(this, void 0, void 0, function* () {
                try {
                    yield asg_utils_1.continueLifecycle(this.autoScalingClient, this.options.autoScalingGroupName, this.options.lifecycleHookName, this.options.lifecycleActionToken, this.instanceId);
                }
                catch (e) {
                    console.log(chalk_1.default.bgRedBright(`Failed to continue ASG lifecycle`), e);
                    return;
                }
            }));
        }
        catch (e) {
            console.log(chalk_1.default.bgRedBright(`Something failed during SSL certificate backup`), e);
            return;
        }
    }
    backupCert() {
        return __awaiter(this, void 0, void 0, function* () {
            console.log(chalk_1.default.bgGreenBright(`Backing up SSL certificate from EC2 instance ${this.instanceId}`));
            const domainName = this.options.domainName;
            let certPem = fs_utils_1.getFile(`/etc/letsencrypt/live/${domainName}/cert.pem`);
            let chainPem = fs_utils_1.getFile(`/etc/letsencrypt/live/${domainName}/chain.pem`);
            let privkeyPem = fs_utils_1.getFile(`/etc/letsencrypt/live/${domainName}/privkey.pem`);
            let fullchainPem = fs_utils_1.getFile(`/etc/letsencrypt/live/${domainName}/fullchain.pem`);
            if (typeof certPem === 'undefined' ||
                typeof chainPem === 'undefined' ||
                typeof privkeyPem === 'undefined' ||
                typeof fullchainPem === 'undefined') {
                console.log(chalk_1.default.bgYellowBright(`Not backing up ssl cert because one or more certificate files are mising/cannot be read in /etc/letsencrypt/live/${domainName}`));
                return;
            }
            try {
                const result = yield Promise.all([
                    s3_utils_1.putObject(this.s3Client, this.options.bucketName, `letsencrypt/${domainName}/cert.pem`, certPem),
                    s3_utils_1.putObject(this.s3Client, this.options.bucketName, `letsencrypt/${domainName}/chain.pem`, chainPem),
                    s3_utils_1.putObject(this.s3Client, this.options.bucketName, `letsencrypt/${domainName}/privkey.pem`, privkeyPem),
                    s3_utils_1.putObject(this.s3Client, this.options.bucketName, `letsencrypt/${domainName}/fullchain.pem`, fullchainPem)
                ]);
                console.log(chalk_1.default.greenBright(`Successfully uploaded certificate to ${this.options.bucketName}`), result);
            }
            catch (e) {
                console.log(chalk_1.default.bgRedBright(`Failed to upload certificate to ${this.options.bucketName}`), e);
                return;
            }
        });
    }
}
exports.BackupSslCert = BackupSslCert;
//# sourceMappingURL=backup-ssl-cert.js.map