"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.putObject = exports.getObject = exports.objectExists = void 0;
const chalk_1 = __importDefault(require("chalk"));
const objectExists = (s3Client, Bucket, Key) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield s3Client
            .headObject({
            Bucket,
            Key
        })
            .promise();
        return true;
    }
    catch (e) {
        console.log(chalk_1.default.bgRedBright(`${Key} not found in s3 bucket ${Bucket}`));
        return false;
    }
});
exports.objectExists = objectExists;
const getObject = (s3Client, Bucket, Key) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    try {
        const response = yield s3Client
            .getObject({
            Bucket,
            Key
        })
            .promise();
        if (typeof response.Body === 'undefined') {
            throw new Error(`Body of ${Key} is undefined`);
        }
        return (_a = response.Body) === null || _a === void 0 ? void 0 : _a.toString('utf-8');
    }
    catch (e) {
        console.log(chalk_1.default.bgRedBright(`Failed to get ${Key} from s3 bucket ${Bucket}`));
        throw e;
    }
});
exports.getObject = getObject;
const putObject = (s3Client, Bucket, Key, Body) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        yield s3Client
            .putObject({
            Bucket,
            Key,
            Body
        })
            .promise();
    }
    catch (e) {
        console.log(chalk_1.default.bgRedBright(`Failed to put object ${Key} in s3 bucket ${Bucket}`));
        throw e;
    }
});
exports.putObject = putObject;
//# sourceMappingURL=s3-utils.js.map